@@ -42,7 +42,7 @@ def detect_volume(
   cmd = (ffmpeg
     .input(input_file)
     .filter('volumedetect')
-    .output(devnull(), format='null', **kwargs)
+    .output(devnull, format='null', **kwargs)
     .compile())
   p = subprocess.run(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
   output = p.stdout.decode('utf-8').splitlines()
