@@ -2,12 +2,11 @@ __all__ = [
   'encode_all',
   'encode_webm',
   'encode_mp3',
-  'mux_folder',
+  'mux_clean_directory',
   'mux_clean',
 ]
 
 
-import argparse
 import os
 from typing import Union
 
@@ -16,7 +15,7 @@ import ffmpeg
 from . import audio, common, video
 
 
-def mux_folder(
+def mux_clean_directory(
     input_dir: str,
     input_audio: str,
     output_dir: str = './clean/',
@@ -31,6 +30,9 @@ def mux_folder(
         norm)
 
 
+mux_folder = mux_clean_directory
+
+
 def mux_clean(
     input_video: str,
     input_audio: str,
@@ -76,7 +78,8 @@ def encode_all(
   if norm:
     print('Detecting input volume')
     af = dict(af, **audio.get_norm_filter(input_file, **kwargs))
-  probe_data = video.probe_dimensions(input_file).update(override_dimensions)
+  probe_data = video.probe_dimensions(input_file)
+  probe_data.update(override_dimensions)
   # common settings
   common_settings = dict(
     common.map_settings,
@@ -88,7 +91,7 @@ def encode_all(
   for resolution in resolutions:
     output_file = os.path.join(output_dir, '{res}.{ext}'.format(
       res=resolution,
-      ext='mp3' if resolution == 0 else '.webm'))
+      ext='mp3' if resolution == 0 else 'webm'))
     if resolution == 0:
       audio.encode_mp3(
         input_file, output_file,
@@ -110,45 +113,3 @@ def encode_all(
         **audio.opus_settings,
         **common_settings)
 
-
-if __name__ == "__main__":
-  parser = argparse.ArgumentParser()
-  parser.add_argument('-i', type=str, required=True, help='input video')
-  parser.add_argument('-crf', type=int, help='constant rate factor')
-  parser.add_argument('-g', type=int, help='interval between keyframes')
-  parser.add_argument('-vf', '-filter:v', type=str, default='', help='video filter string')
-  parser.add_argument('-af', '-filter:a', type=str, default='', help='audio filter string')
-  parser.add_argument('-ss', type=str, help='start time')
-  parser.add_argument('-to', type=str, help='end time')
-  parser.add_argument('-t', type=str, help='encode duration')
-  parser.add_argument('-norm', action='store_true', help='normalize output volume')
-  parser.add_argument('-outdir', type=str, help='output path')
-  parser.add_argument('-skip', type=int, nargs='+', help='resolutions to skip')
-  parser.set_defaults(
-    norm=False,
-    outdir='./source/',
-    skip=[]
-  )
-  args = parser.parse_args()
-
-  if not os.path.isfile(args.i):
-    print('invalid input file provided')
-    exit()
-  
-  kwargs = {k: v for k, v in {
-    'ss': args.ss,
-    'to': args.to,
-    't': args.t}.items() if not v == None}
-
-  vp9_settings = {k: v for k, v in {
-    'crf': args.crf,
-    'g': args.g}.items() if not v == None}
-
-  resolutions = [res for res in video.resolutions if res not in args.skip]
-
-  encode_all(
-    args.i, args.outdir,
-    vf=args.vf, af=args.af,
-    norm=args.norm,
-    vp9_settings=vp9_settings,
-    **kwargs)
